@@ -11,6 +11,7 @@ from celery import concurrency
 from celery.bin.base import (COMMA_SEPARATED_LIST, LOG_LEVEL,
                              CeleryDaemonCommand, CeleryOption,
                              handle_preload_options)
+from celery.exceptions import SecurityError
 from celery.platforms import (EX_FAILURE, EX_OK, detached,
                               maybe_drop_privileges)
 from celery.utils.log import get_logger
@@ -39,13 +40,25 @@ class WorkersPool(click.Choice):
 
     def __init__(self):
         """Initialize the workers pool option with the relevant choices."""
-        super().__init__(('prefork', 'eventlet', 'gevent', 'solo'))
+        super().__init__(concurrency.get_available_pool_names())
 
     def convert(self, value, param, ctx):
         # Pools like eventlet/gevent needs to patch libs as early
         # as possible.
-        return concurrency.get_implementation(
-            value) or ctx.obj.app.conf.worker_pool
+        value = super().convert(value, param, ctx)
+        worker_pool = ctx.obj.app.conf.worker_pool
+        if value == 'prefork' and worker_pool:
+            # If we got the default pool through the CLI
+            # we need to check if the worker pool was configured.
+            # If the worker pool was configured, we shouldn't use the default.
+            value = concurrency.get_implementation(worker_pool)
+        else:
+            value = concurrency.get_implementation(value)
+
+            if not value:
+                value = concurrency.get_implementation(worker_pool)
+
+        return value
 
 
 class Hostname(StringParamType):
@@ -139,7 +152,8 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
               '--statedb',
               cls=CeleryOption,
               type=click.Path(),
-              callback=lambda ctx, _, value: value or ctx.obj.app.conf.worker_state_db,
+              callback=lambda ctx, _,
+              value: value or ctx.obj.app.conf.worker_state_db,
               help_group="Worker Options",
               help="Path to the state database. The extension '.db' may be "
                    "appended to the filename.")
@@ -160,7 +174,8 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
 @click.option('--prefetch-multiplier',
               type=int,
               metavar="<prefetch multiplier>",
-              callback=lambda ctx, _, value: value or ctx.obj.app.conf.worker_prefetch_multiplier,
+              callback=lambda ctx, _,
+              value: value or ctx.obj.app.conf.worker_prefetch_multiplier,
               cls=CeleryOption,
               help_group="Worker Options",
               help="Set custom prefetch multiplier value"
@@ -169,7 +184,8 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
               '--concurrency',
               type=int,
               metavar="<concurrency>",
-              callback=lambda ctx, _, value: value or ctx.obj.app.conf.worker_concurrency,
+              callback=lambda ctx, _,
+              value: value or ctx.obj.app.conf.worker_concurrency,
               cls=CeleryOption,
               help_group="Pool Options",
               help="Number of child processes processing the queue.  "
@@ -267,7 +283,8 @@ def detach(path, argv, logfile=None, pidfile=None, uid=None,
 @click.option('-s',
               '--schedule-filename',
               '--schedule',
-              callback=lambda ctx, _, value: value or ctx.obj.app.conf.beat_schedule_filename,
+              callback=lambda ctx, _,
+              value: value or ctx.obj.app.conf.beat_schedule_filename,
               cls=CeleryOption,
               help_group="Embedded Beat Options")
 @click.option('--scheduler',
@@ -289,40 +306,45 @@ def worker(ctx, hostname=None, pool_cls=None, app=None, uid=None, gid=None,
     $ celery worker --autoscale=10,0
 
     """
-    app = ctx.obj.app
-    if ctx.args:
-        try:
-            app.config_from_cmdline(ctx.args, namespace='worker')
-        except (KeyError, ValueError) as e:
-            # TODO: Improve the error messages
-            raise click.UsageError(
-                "Unable to parse extra configuration from command line.\n"
-                f"Reason: {e}", ctx=ctx)
-    if kwargs.get('detach', False):
-        argv = ['-m', 'celery'] + sys.argv[1:]
-        if '--detach' in argv:
-            argv.remove('--detach')
-        if '-D' in argv:
-            argv.remove('-D')
+    try:
+        app = ctx.obj.app
+        if ctx.args:
+            try:
+                app.config_from_cmdline(ctx.args, namespace='worker')
+            except (KeyError, ValueError) as e:
+                # TODO: Improve the error messages
+                raise click.UsageError(
+                    "Unable to parse extra configuration from command line.\n"
+                    f"Reason: {e}", ctx=ctx)
+        if kwargs.get('detach', False):
+            argv = ['-m', 'celery'] + sys.argv[1:]
+            if '--detach' in argv:
+                argv.remove('--detach')
+            if '-D' in argv:
+                argv.remove('-D')
 
-        return detach(sys.executable,
-                      argv,
-                      logfile=logfile,
-                      pidfile=pidfile,
-                      uid=uid, gid=gid,
-                      umask=kwargs.get('umask', None),
-                      workdir=kwargs.get('workdir', None),
-                      app=app,
-                      executable=kwargs.get('executable', None),
-                      hostname=hostname)
+            return detach(sys.executable,
+                          argv,
+                          logfile=logfile,
+                          pidfile=pidfile,
+                          uid=uid, gid=gid,
+                          umask=kwargs.get('umask', None),
+                          workdir=kwargs.get('workdir', None),
+                          app=app,
+                          executable=kwargs.get('executable', None),
+                          hostname=hostname)
 
-    maybe_drop_privileges(uid=uid, gid=gid)
-    worker = app.Worker(
-        hostname=hostname, pool_cls=pool_cls, loglevel=loglevel,
-        logfile=logfile,  # node format handled by celery.app.log.setup
-        pidfile=node_format(pidfile, hostname),
-        statedb=node_format(statedb, hostname),
-        no_color=ctx.obj.no_color,
-        **kwargs)
-    worker.start()
-    return worker.exitcode
+        maybe_drop_privileges(uid=uid, gid=gid)
+        worker = app.Worker(
+            hostname=hostname, pool_cls=pool_cls, loglevel=loglevel,
+            logfile=logfile,  # node format handled by celery.app.log.setup
+            pidfile=node_format(pidfile, hostname),
+            statedb=node_format(statedb, hostname),
+            no_color=ctx.obj.no_color,
+            quiet=ctx.obj.quiet,
+            **kwargs)
+        worker.start()
+        return worker.exitcode
+    except SecurityError as e:
+        ctx.obj.error(e.args[0])
+        ctx.exit(1)
