@@ -1,7 +1,4 @@
-# -*- coding: utf-8 -*-
 """X.509 certificates."""
-from __future__ import absolute_import, unicode_literals
-
 import datetime
 import glob
 import os
@@ -12,14 +9,13 @@ from cryptography.x509 import load_pem_x509_certificate
 from kombu.utils.encoding import bytes_to_str, ensure_bytes
 
 from celery.exceptions import SecurityError
-from celery.five import values
 
 from .utils import reraise_errors
 
 __all__ = ('Certificate', 'CertStore', 'FSCertStore')
 
 
-class Certificate(object):
+class Certificate:
     """X.509 certificate."""
 
     def __init__(self, cert):
@@ -31,7 +27,7 @@ class Certificate(object):
 
     def has_expired(self):
         """Check if the certificate has expired."""
-        return datetime.datetime.now() > self._cert.not_valid_after
+        return datetime.datetime.utcnow() >= self._cert.not_valid_after
 
     def get_pubkey(self):
         """Get public key from certificate."""
@@ -47,7 +43,7 @@ class Certificate(object):
 
     def get_id(self):
         """Serial number/issuer pair uniquely identifies a certificate."""
-        return '{0} {1}'.format(self.get_issuer(), self.get_serial_number())
+        return f'{self.get_issuer()} {self.get_serial_number()}'
 
     def verify(self, data, signature, digest):
         """Verify signature for string containing data."""
@@ -61,7 +57,7 @@ class Certificate(object):
                                      ensure_bytes(data), padd, digest)
 
 
-class CertStore(object):
+class CertStore:
     """Base class for certificate stores."""
 
     def __init__(self):
@@ -69,20 +65,19 @@ class CertStore(object):
 
     def itercerts(self):
         """Return certificate iterator."""
-        for c in values(self._certs):
-            yield c
+        yield from self._certs.values()
 
     def __getitem__(self, id):
         """Get certificate by id."""
         try:
             return self._certs[bytes_to_str(id)]
         except KeyError:
-            raise SecurityError('Unknown certificate: {0!r}'.format(id))
+            raise SecurityError(f'Unknown certificate: {id!r}')
 
     def add_cert(self, cert):
         cert_id = bytes_to_str(cert.get_id())
         if cert_id in self._certs:
-            raise SecurityError('Duplicate certificate: {0!r}'.format(id))
+            raise SecurityError(f'Duplicate certificate: {id!r}')
         self._certs[cert_id] = cert
 
 
@@ -98,5 +93,5 @@ class FSCertStore(CertStore):
                 cert = Certificate(f.read())
                 if cert.has_expired():
                     raise SecurityError(
-                        'Expired certificate: {0!r}'.format(cert.get_id()))
+                        f'Expired certificate: {cert.get_id()!r}')
                 self.add_cert(cert)
